<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema">

  <xsl:output method="text"/>
	
  <xsl:variable name="smallCase" select="'abcdefghijklmnopqrstuvwxyz'" />
  <xsl:variable name="upperCase" select="'ABCDEFGHIJKLMNOPQRSTUVWXYZ'" />
	
  <xsl:template match="/xs:schema">
    <xsl:result-document href="{xs:element/@name}.java">
      public class <xsl:value-of select="xs:element/@name"/> {
        public static void main(String[] args) {
          <xsl:value-of select="xs:element/@type"/> obj;
        }
      }	    
    </xsl:result-document>
    <xsl:apply-templates select="xs:complexType"/>
  </xsl:template>
	
  <xsl:template match="xs:complexType">
    <xsl:result-document href="{@name}.java">
      public class <xsl:value-of select="@name"/> {
      <xsl:for-each select="xs:sequence/xs:element | xs:attribute">
	<xsl:choose>
    	  <xsl:when test="@type = 'xs:string'">
	    String <xsl:value-of select="@name"/>;
	  </xsl:when>
	  <xsl:when test="@type = 'xs:integer'">
	    int <xsl:value-of select="@name"/>;
	  </xsl:when>
	  <xsl:when test="@type = 'xs:float'">
	    float <xsl:value-of select="@name"/>;
	  </xsl:when>
	</xsl:choose>
      </xsl:for-each>
      <xsl:for-each select="xs:sequence/xs:element | xs:attribute">
        <xsl:variable name="NAME">
          <xsl:choose>
  	    <xsl:when test="contains($smallCase, substring(@name, 1, 1))">
	      <xsl:value-of select="concat(translate(substring(@name, 1, 1), $smallCase, $upperCase), substring(@name, 2))" />
	    </xsl:when>
	    <xsl:when test="contains($upperCase, substring(@name, 1, 1))">
	      <xsl:value-of select="concat(translate(substring(@name, 1, 1), $upperCase, $smallCase), substring(@name, 2))" />
	    </xsl:when>
	  </xsl:choose>
	</xsl:variable>
	<xsl:choose>
	  <xsl:when test="@type = 'xs:string'">
	    public String get<xsl:value-of select="$NAME" />() {
	      return <xsl:value-of select="@name" />;
	    }
		   
	    public void set<xsl:value-of select="$NAME" />(String x) {
	      this.<xsl:value-of select="@name" /> = x;
	    }					   
	  </xsl:when>
	  <xsl:when test="@type = 'xs:integer'">
	    public int get<xsl:value-of select="$NAME" />() {
	      return <xsl:value-of select="@name" />;
	    }
					   
	    public void set<xsl:value-of select="$NAME" />(int x) {
	      this.<xsl:value-of select="@name" /> = x;
	    }	
	  </xsl:when>
	  <xsl:when test="@type = 'xs:float'">
	    public float get<xsl:value-of select="$NAME" />() {
	      return <xsl:value-of select="@name" />;
	    }
					   
	    public void set<xsl:value-of select="$NAME" />(float x) {
	      this.<xsl:value-of select="@name" /> = x;
	    }	
	  </xsl:when>
	</xsl:choose>
      </xsl:for-each>
    }
    </xsl:result-document>
  </xsl:template>
	
</xsl:stylesheet>
